from jinja2.environment import Environment, Template
from jinja2.loaders import FileSystemLoader
import yaml
from yaml.loader import FullLoader


class Yex:
    def __init__(self, templates_path):
        """Init with yaml templates folder"""
        self._env = Environment(loader=FileSystemLoader(templates_path))

    def render_file(self, file, *args, **context):
        """Render yaml with context"""
        template = self._env.get_template(file)
        yaml_text = self._render(template, *args, **context)
        return self._load(yaml_text)

    @classmethod
    def render_text(cls, text, *args, **context):
        """Render pure yaml text template with context"""
        template = Template(text)
        yaml_text = cls._render(template, *args, **context)
        return cls._load(yaml_text)

    @staticmethod
    def _render(template: Template, *args, **kwargs):
        return template.render(*args, **kwargs)

    @staticmethod
    def _load(text: str):
        return yaml.load(text, Loader=FullLoader)



import os
from setuptools import setup


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name="yaml-expressions",
    version="0.1.2",
    author="Mikhail Yudin",
    author_email="fagci.nsk@gmail.com",
    description=("Jinja2 templates for yaml. Make dynamic rules and configs."),
    license="MIT",
    keywords="yaml jinja2 exptessions template",
    url="https://github.com/fagcinsk/yaml-expressions",
    packages=['yex'],
    install_requires=['pyyaml', 'jinja2'],
    long_description=read('README.md'),
    long_description_content_type='text/markdown',
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Utilities",
        "License :: OSI Approved :: MIT License",
    ],
)
